@@ -41,13 +41,13 @@ class SequenceEmbeddingLengthMismatchException(Exception):
     """
 
 
-class FileDoesntExistError(Exception):
-    """
-    Exception for invalid file download request
-    """
-
 class MD5ClashException(Exception):
     """
     When remapping sequences from a fasta file, if there is an MD5 clash, this will stop the execution
     """
 
+
+class TooFewComponentsException(InvalidParameterError):
+    """
+    Thrown when n_components is nonsensical (e.g. < 2)
+    """
\ No newline at end of file
